==> edjchain-1.0.3.tgz: package/exports/function.js <==
"use strict";

const invoke = require("../interface/invoke");
const query = require("../interface/query");

exports.recordFunction = async function(
  functionId,
  functionName,
  applicationId,
  bundleURL,
  bundleHash,
  functionEncoded,
  functionStatus
) {
  try {
    const payload = {
      functionId,
      functionName,
      applicationId,
      bundleURL,
      bundleHash,
      functionEncoded,
      functionStatus
    };
    await invoke(req.body.user, "recordFunction", payload);
    return "transaction submitted";
  } catch (err) {
    return err;
  }
};

exports.updateFunction = async function(
  functionId,
  functionName,
  applicationId,
  bundleURL,
  bundleHash,
  functionEncoded,
  functionStatus
) {
  try {
    const payload = {
      functionId,
      functionName,
      applicationId,
      bundleURL,
      bundleHash,
      functionEncoded,
      functionStatus
    };
    await invoke(req.body.user, "updateFunction", payload);
    return "transaction submitted";
  } catch (err) {
    return err;
  }
};

exports.queryFunction = async function(functionId) {
  try {
    const queryJSON = {
      functionId
    };
    return await query(req.body.user, "queryFunction", queryJSON);
  } catch (err) {
    res.status(500).send(err);
  }
};

exports.queryFunctionHistory = async function() {
  // stub
};

exports.queryFunctionList = async function() {
  try {
    return await query(req.body.user, "queryFunctionList");
  } catch (err) {
    return err;
  }
};

exports.deleteFunction = async function(functionId) {
  try {
    const payload = {
      functionId
    };
    await invoke(req.body.user, "deleteFunction", payload);
    return "transaction submitted";
  } catch (err) {
    return err;
  }
};

==> edjchain-1.0.12.tgz: package/exports/function.js <==
"use strict";

const invoke = require("../interface/invoke");
const query = require("../interface/query");

exports.recordFunction = async function(
  user,
  functionId,
  functionName,
  applicationId,
  bundleURL,
  bundleHash,
  functionEncoded,
  functionStatus
) {
  try {
    const payload = {
      functionId,
      functionName,
      applicationId,
      bundleURL,
      bundleHash,
      functionEncoded,
      functionStatus
    };
    await invoke(user, "recordFunction", payload);
    return "transaction submitted";
  } catch (err) {
    return err;
  }
};

exports.updateFunction = async function(
  user,
  functionId,
  functionName,
  applicationId,
  bundleURL,
  bundleHash,
  functionEncoded,
  functionStatus
) {
  try {
    const payload = {
      functionId,
      functionName,
      applicationId,
      bundleURL,
      bundleHash,
      functionEncoded,
      functionStatus
    };
    await invoke(user, "updateFunction", payload);
    return "transaction submitted";
  } catch (err) {
    return err;
  }
};

exports.queryFunction = async function(user, functionId) {
  try {
    const queryJSON = {
      functionId
    };
    return await query(user, "queryFunction", queryJSON);
  } catch (err) {
    return err;
  }
};

exports.queryFunctionHistory = async function() {
  // stub
};

exports.queryFunctionList = async function(user) {
  try {
    return await query(user, "queryFunctionList");
  } catch (err) {
    return err;
  }
};

exports.deleteFunction = async function(user, functionId) {
  try {
    const payload = {
      functionId
    };
    await invoke(user, "deleteFunction", payload);
    return "transaction submitted";
  } catch (err) {
    return err;
  }
};
